@@ -43,7 +43,7 @@ has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Clinking Beer Mugs';
-our $VERSION  = '6.08';
+our $VERSION  = '6.09';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -791,6 +791,8 @@ Andrew Fresh
 
 Andrey Khozov
 
+Andrey Kuzmin
+
 Andy Grundman
 
 Aristotle Pagaltzis
@@ -961,6 +963,8 @@ Rafal Pocztarski
 
 Randal Schwartz
 
+Richard Elberger
+
 Rick Delaney
 
 Robert Hicks
