@@ -72,7 +72,8 @@ and implements the following new ones.
 
   my $route = $plugin->register(Mojolicious->new, {'/foo' => '/some/app.pl'});
 
-Mount L<Mojolicious> application.
+Mount L<Mojolicious> application and return the generated route, which is
+usually a L<Mojolicious::Routes::Route> object.
 
 =head1 SEE ALSO
 
