@@ -1,6 +1,7 @@
 package Mojolicious::Plugins;
 use Mojo::Base 'Mojo::EventEmitter';
 
+use Mojo::Loader 'load_class';
 use Mojo::Util 'camelize';
 
 has namespaces => sub { ['Mojolicious::Plugin'] };
@@ -47,8 +48,7 @@ sub register_plugin {
 
 sub _load {
   my $module = shift;
-  return $module->isa('Mojolicious::Plugin')
-    unless my $e = Mojo::Loader->new->load($module);
+  return $module->isa('Mojolicious::Plugin') unless my $e = load_class $module;
   ref $e ? die $e : return undef;
 }
 
