@@ -83,6 +83,13 @@ sub content_type_unlike {
 
 sub delete_ok { shift->_build_ok(DELETE => @_) }
 
+sub element_count_is {
+  my ($self, $selector, $count, $desc) = @_;
+  $desc ||= encode 'UTF-8', qq{element count for selector "$selector"};
+  my $size = $self->tx->res->dom->find($selector)->size;
+  return $self->_test('is', $size, $count, $desc);
+}
+
 sub element_exists {
   my ($self, $selector, $desc) = @_;
   $desc ||= encode 'UTF-8', qq{element for selector "$selector" exists};
@@ -618,6 +625,14 @@ Opposite of L</"content_type_like">.
 Perform a C<DELETE> request and check for transport errors, takes the same
 arguments as L<Mojo::UserAgent/"delete">, except for the callback.
 
+=head2 element_count_is
+
+  $t = $t->element_count_is('div.foo[x=y]', 5);
+  $t = $t->element_count_is('html body div', 30, 'thirty elements');
+
+Checks the number of HTML/XML elements matched by the CSS selector with
+L<Mojo::DOM/"find">.
+
 =head2 element_exists
 
   $t = $t->element_exists('div.foo[x=y]');
